pub fn merge_outcome_signals(
existing: &[OutcomeSignal],
incoming: &[OutcomeSignal],
) -> Vec<OutcomeSignal>Expand description
Merge outcome signals, replacing older entries of the same kind with the newest.
pub fn merge_outcome_signals(
existing: &[OutcomeSignal],
incoming: &[OutcomeSignal],
) -> Vec<OutcomeSignal>Merge outcome signals, replacing older entries of the same kind with the newest.