pub fn reflection_promotion_confidence(
improvement_score: Option<f32>,
outcome_signals: &[OutcomeSignal],
) -> f32Expand description
Score how strongly a reflection should be promoted into durable memory.
pub fn reflection_promotion_confidence(
improvement_score: Option<f32>,
outcome_signals: &[OutcomeSignal],
) -> f32Score how strongly a reflection should be promoted into durable memory.